@@ -13,6 +13,15 @@ use JSON;
 
 App::Spoor::ParsedFileManager
 
+=head1 VERSION
+
+Version 0.04
+
+=cut
+
+our $VERSION = '0.01';
+
+
 =head1 SYNOPSIS
 
 This module is responsible for looping through the contents of the parsed files directory and passing them to the
@@ -65,13 +74,9 @@ sub process_parsed_files {
   my ($source_file_path, $file_contents);
   opendir my $parsed_entries_dir, $config->{parsed_entries_path};
 
-  while(readdir $parsed_entries_dir) {
-    next if (/\A\.{1,2}\z/);
-
-    my ( $sanitised_file_name ) = $_ =~ /\A((error|access|login)\.\d+\.\d+\.json)\z/;
-
-    next unless $sanitised_file_name;
+  my @sanitised_file_names = grep { /\A((error|access|login)\.\d+\.\d+\.json)\z/ } readdir $parsed_entries_dir;
 
+  foreach my $sanitised_file_name (@sanitised_file_names) {
     $source_file_path = File::Spec->catfile($config->{parsed_entries_path}, $sanitised_file_name);
     if ($file_security_check->($source_file_path)) {
       $file_contents = from_json(path($source_file_path)->slurp_utf8());
@@ -83,6 +88,8 @@ sub process_parsed_files {
       }
     }
   }
+
+  closedir $parsed_entries_dir;
 }
 
 =head1 AUTHOR
